many2onedelegate — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

# many2onedelegate

class `camelot.view.controls.delegates.many2onedelegate.` `Many2OneDelegate`(parent=None, admin=None, embedded=False, editable=True, **kwargs)

  Custom delegate for many 2 one relations

  > Once an item has been selected, it is represented by its unicode representation in the editor or the table. So the related classes need an implementation of their __unicode__ method.

  Field attributes supported by the delegate :

  > - admin
  > - embedded
  > - editable

  By default, creates a Many2OneEditor as its editor.

  Field Attributes | Editor
  editable=False tooltip=’tooltip’ |
  editable=True |
  editable=True tooltip=’tooltip’ |
  editable=False |
  editable=False background_color=ColorScheme.green |
  editable=True background_color=ColorScheme.green |

  Static attributes supported by this editor :

  > - admin
  > - editable
  > - field_name

  Dynamic field attributes supported by the editor :

  > - editable
  > - background_color
  > - tooltip

  `editor`

    alias of `Many2OneEditor`

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- delegates »

Comments
blog comments powered by Disqus